@@ -82,11 +82,6 @@ def install_jrnl(config_path='~/.jrnl_config'):
         password = None
         print("PyCrypto not found. To encrypt your journal, install the PyCrypto package from http://www.pycrypto.org or with 'pip install pycrypto' and run 'jrnl --encrypt'. For now, your journal will be stored in plain text.")
 
-    # Use highlighting:
-    if not module_exists("colorama"):
-        print("colorama not found. To turn on highlighting, install colorama and set highlight to true in your .jrnl_conf.")
-        default_config['highlight'] = False
-
     open(default_config['journals']['default'], 'a').close()  # Touch to make sure it's there
 
     # Write config to ~/.jrnl_conf
