@@ -8,6 +8,9 @@ import keyring
 import pytz
 try: import simplejson as json
 except ImportError: import json
+if "win32" in sys.platform:
+    import colorama
+    colorama.init()
 import re
 import tempfile
 import subprocess
@@ -126,11 +129,9 @@ def load_and_fix_json(json_path):
 
 def get_text_from_editor(config, template=""):
     tmpfile = os.path.join(tempfile.gettempdir(), "jrnl")
-    if template:
-        with codecs.open(tmpfile, 'w', "utf-8") as f:
+    with codecs.open(tmpfile, 'w', "utf-8") as f:
+        if template:
             f.write(template)
-    with open(tmpfile, 'w'):
-        pass
     subprocess.call(config['editor'].split() + [tmpfile])
     with codecs.open(tmpfile, "r", "utf-8") as f:
         raw = f.read()
